**Example 1: 文档从房间解绑**



Input: 

```
tccli lcic UnbindDocumentFromRoom --cli-unfold-argument  \
    --DocumentId xx \
    --RoomId 123
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

